@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.96 date 2005-01-27
+ * version 0.97 date 2005-12-29
  * Copyright (C) 2003-2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -419,14 +419,15 @@ void cmd_outfilter_list( char * p_params, st_out_info * p_out_info )
 //add an output port
 void cmd_outport_list_add( char * p_params, st_out_info * p_out_info )
 {
-  char * p_name, * p_addr;
+  char * p_name, * p_addr, * p_timeout;
 
   //get name and address
   tools_str_first_words( p_params, 1, &p_name, &p_params );
   tools_str_first_words( p_params, 3, &p_addr, &p_params );
+  tools_str_first_words( p_params, 1, &p_timeout, &p_params );
 
   //add output port
-  if( outport_add( p_global_outport_list, p_name, p_addr, p_out_info ) != 0 )
+  if( outport_add( p_global_outport_list, p_name, p_addr, p_timeout, p_out_info ) != 0 )
   {
     out_str( p_out_info, "  error: could not add output port \"" );
     out_str( p_out_info, p_name );
@@ -640,7 +641,7 @@ st_cmd_tab cmd_tab[] =
 {
   {
     .name = "dyndest_list",
-    .shortname "ddl",
+    .shortname = "ddl",
     .params = "<outport>",
     .descr = "list all dynamic destinations of an output port",
     .func = cmd_dyndest_list,
@@ -651,7 +652,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "dynsrc_add",
-    .shortname "dsa",
+    .shortname = "dsa",
     .params = "<inport> <name> <addr-fam> <addr> <port> <protocol> <interval>",
     .descr = "add a dynamic source to an input port",
     .func = cmd_dynsrc_list_add,
@@ -666,7 +667,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "dynsrc_del",
-    .shortname "dsd",
+    .shortname = "dsd",
     .params = "<inport> <name>",
     .descr = "delete a dynamic source from an input port",
     .func = cmd_dynsrc_list_del,
@@ -677,7 +678,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "dynsrc_list",
-    .shortname "dsl",
+    .shortname = "dsl",
     .params = "<inport>",
     .descr = "list all dynamic sources of an input port",
     .func = cmd_dynsrc_list,
@@ -711,7 +712,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "infilter_add",
-    .shortname "ifa",
+    .shortname = "ifa",
     .params = "<inport> <index> <addr-fam> <net/mask> <port-port> {<protcol>|any} {<format>|-} <stream-name> [stop] [<outport-name> <priority> <timeout>]",
     .descr = "add an input filter rule to an input port",
     .func = cmd_infilter_list_add,
@@ -732,7 +733,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "infilter_del",
-    .shortname "ifd",
+    .shortname = "ifd",
     .params = "<inport> <index>",
     .descr = "delete an input filter rule from an input port",
     .func = cmd_infilter_list_del,
@@ -743,7 +744,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "infilter_list",
-    .shortname "ifl",
+    .shortname = "ifl",
     .params = "<inport>",
     .descr = "list all input filter rules of an input port",
     .func = cmd_infilter_list,
@@ -775,7 +776,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "inport_list",
-    .shortname "ipl",
+    .shortname = "ipl",
     .params = NULL,
     .descr = "list all input ports",
     .func = cmd_inport_list,
@@ -785,7 +786,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "outfilter_add",
-    .shortname "ofa",
+    .shortname = "ofa",
     .params = "<outport> <index> <addr-fam> <net/mask> <port-port> {<protocol>|any} <dest-name> {deny|<timeout>} [<format>]",
     .descr = "add an output filter rule to an output port",
     .func = cmd_outfilter_list_add,
@@ -804,7 +805,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "outfilter_del",
-    .shortname "ofd",
+    .shortname = "ofd",
     .params = "<outport> <index>",
     .descr = "delete an output filter rule from an output port",
     .func = cmd_outfilter_list_del,
@@ -815,7 +816,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "outfilter_list",
-    .shortname "ofl",
+    .shortname = "ofl",
     .params = "<outport>",
     .descr = "list all output filter rules of an output port",
     .func = cmd_outfilter_list,
@@ -827,10 +828,11 @@ st_cmd_tab cmd_tab[] =
   {
     .name = "outport_add",
     .shortname = "opa",
-    .params = "<name> <addr-fam> <host> <port>",
+    .params = "<name> <addr-fam> <host> <port> [<timeout>]",
     .descr = "add an output port",
     .func = cmd_outport_list_add,
     .description = "  creates a new output port called <name> at <addr-fam> <host> <port>\n"
+                   "  with a timeout (repetition interval of last packet) of <timeout> ms\n"
                    "  \n"
                    "  e.g.: \"outport_add my_outport in 0.0.0.0 23230\"\n"
                    "  e.g.: \"outport_add my_outport_ipv6 in6 0 23230\"\n",
@@ -847,7 +849,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "outport_list",
-    .shortname "opl",
+    .shortname = "opl",
     .params = NULL,
     .descr = "list all output ports",
     .func = cmd_outport_list,
@@ -865,7 +867,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "statdest_add",
-    .shortname "sda",
+    .shortname = "sda",
     .params = "<outport> <name> <addr-fam> <addr> <port> <protocol> [<format>]",
     .descr = "add a static destination to an output port",
     .func = cmd_statdest_list_add,
@@ -879,7 +881,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "statdest_del",
-    .shortname "sdd",
+    .shortname = "sdd",
     .params = "<outport> <name>",
     .descr = "delete a static destination from an output port",
     .func = cmd_statdest_list_del,
@@ -890,7 +892,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "statdest_format",
-    .shortname "sdf",
+    .shortname = "sdf",
     .params = "<outport> <name> [<format>]",
     .descr = "set new picture format for a static destination of an output port",
     .func = cmd_statdest_list_format,
@@ -901,7 +903,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "statdest_list",
-    .shortname "sdl",
+    .shortname = "sdl",
     .params = "<outport>",
     .descr = "list all static destinations of an output port",
     .func = cmd_statdest_list,
@@ -912,7 +914,7 @@ st_cmd_tab cmd_tab[] =
   },
   {
     .name = "stream_list",
-    .shortname "stl",
+    .shortname = "stl",
     .params = "<outport>",
     .descr = "list all streams of an output port",
     .func = cmd_stream_list,
