@@ -1,6 +1,6 @@
 /* BLINKENLIGHTS PROXY
- * version 0.95 date 2004-09-30
- * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
+ * version 0.97 date 2005-12-29
+ * Copyright (C) 2003-2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
 
@@ -31,7 +31,7 @@ void outport_free( st_outport_list * p_outport_list );
 
 //add an output port to an output port list
 //returns 0 on success, a negative value in case of error
-int outport_add( st_outport_list * p_outport_list, char * p_name, char * p_addr, st_out_info * p_out_info );
+int outport_add( st_outport_list * p_outport_list, char * p_name, char * p_addr, char * p_timeout, st_out_info * p_out_info );
 
 //delete an output port from an output port list
 //returns 0 on success, a negative value in case of error
@@ -80,4 +80,7 @@ void outport_process( st_outport_list * p_outport_list, st_select_fd_sets * p_fd
 //send a frame to all destinations of output port
 void outport_send_frame( st_outport_data * p_outport_data, st_frame * p_frame );
 
+//send the last frame to all destinations of output port
+void outport_send_last_frame( st_outport_data * p_outport_data );
+
 #endif //#ifndef INC_outport
