@@ -1,13 +1,13 @@
 /* BLINKENLIGHTS PROXY
- * version 0.95 date 2004-09-30
- * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
+ * version 0.97 date 2005-12-29
+ * Copyright (C) 2003-2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <malloc.h>
+#include <stdlib.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -573,6 +573,18 @@ static void frame_convert( st_format * p_src_format, unsigned char * p_src_data,
   unsigned long src_skip, dest_skip, src_i, dest_i;
   unsigned short val, src_maxval, dest_maxval, src_div;
 
+  //formats are exactly the same
+  if( p_src_format->height == p_dest_format->height
+   && p_src_format->width == p_dest_format->width
+   && p_src_format->channels == p_dest_format->channels
+   && p_src_format->colors == p_dest_format->colors )
+  {
+    //simply copy data
+    memcpy( p_dest_data, p_src_data, p_src_format->height * p_src_format->width * p_src_format->channels );
+    //done
+    return;
+  }
+
   //get y values
   if( p_src_format->height < p_dest_format->height )
   {
@@ -738,6 +750,7 @@ void proto_send_close( int sock, et_proto proto, st_addr * p_addr )
     //unknown protocol
     case proto_none:
     default:
+      ;
   } //switch( proto )
 }
 
@@ -780,20 +793,9 @@ void proto_send_frame( int sock, et_proto proto, st_addr * p_addr, st_format for
     //unknown protocol
     case proto_none:
     default:
+      ;
   } //switch( proto )
 
-  //formats are exactly the same
-  if( p_frame->format.height == format.height
-   && p_frame->format.width == format.width
-   && p_frame->format.channels == format.channels
-   && p_frame->format.colors == format.colors )
-  {
-    //send original packet
-    sendto( sock, p_frame->p_msg, p_frame->msg_len, 0, &p_addr->sa.sa, p_addr->sa_len );
-    //done
-    return;
-  }
-
   //switch by protocol
   switch( proto )
   {
