@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.96 date 2005-01-27
+ * version 0.97 date 2005-12-29
  * Copyright (C) 2003-2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -38,4 +38,7 @@ void stream_tick( st_stream_list * p_stream_list );
 //send current frame to a destination
 void stream_send_current_frame( st_stream_list * p_stream_list, et_proto proto, st_addr * p_addr, st_format * p_format );
 
+//get current frame of a stream list
+st_frame * stream_get_cur_frame( st_stream_list * p_stream_list );
+
 #endif //#ifndef INC_stream
